@@ -9,8 +9,8 @@
 #' \tabular{ll}{ 
 #' Package: \tab crawl\cr 
 #' Type: \tab Package\cr 
-#' Version: \tab 2.0.1\cr 
-#' Date: \tab July 22, 2016\cr 
+#' Version: \tab 2.1.1\cr 
+#' Date: \tab April 21, 2017\cr 
 #' License: \tab CC0 \cr 
 #' LazyLoad: \tab yes\cr 
 #' }
@@ -32,13 +32,14 @@
 #' @references Johnson, D., J. London, M. -A. Lea, and J. Durban (2008)
 #' Continuous-time correlated random walk model for animal telemetry data.
 #' Ecology 89(5) 1208-1215.
+#' @import dplyr
 #' @importFrom Rcpp evalCpp
 #' @importFrom graphics layout
 #' @importFrom methods as slot 
-#' @importFrom stats approx filter model.frame model.matrix 
+#' @importFrom stats approx model.frame model.matrix 
 #'             na.pass optim pchisq pexp pnorm qnorm 
-#'             rchisq runif sd
-#' @useDynLib crawl
+#'             rchisq runif sd setNames
+#' @useDynLib crawl, .registration = TRUE
 
 NULL
 
@@ -134,12 +135,9 @@ NULL
   date <- info$Date
   packageStartupMessage(
     paste(paste(package, version, paste("(",date, ")", sep=""), "\n"), 
-          "Type 'vignette('crawl_intro')' to see examples of package use, and\n",
-          "'demo(package='crawl')' will provide a list of demos.\n",
-          "The raw code for the demos can be found by typing:\n",
-          "'system.file('demo', package='crawl')'\n")
+          "Demos and documentation can be found at our new GitHub repository:\n",
+          "https://dsjohnson.github.io/crawl_examples/")
   )
-  
 }
 
 # .onUnload <- function(libpath)
